@@ -37,9 +37,7 @@
 
 #include <QListWidget>
 
-namespace IncidenceEditorNG
-{
-
+namespace IncidenceEditorNG {
 class AttachmentIconView : public QListWidget
 {
     Q_OBJECT
@@ -51,9 +49,9 @@ public:
     QUrl tempFileForAttachment(const KCalCore::Attachment::Ptr &attachment) const;
 
 protected:
-    QMimeData *mimeData(const QList<QListWidgetItem *> items) const Q_DECL_OVERRIDE;
-    void startDrag(Qt::DropActions supportedActions) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
+    QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
+    void startDrag(Qt::DropActions supportedActions) override;
+    void keyPressEvent(QKeyEvent *event) override;
 
 private:
     mutable QHash<KCalCore::Attachment::Ptr, QUrl> mTempFiles;
@@ -91,7 +89,6 @@ private:
     KCalCore::Attachment::Ptr mAttachment;
     QString mSaveUri;
 };
-
 }
 
 #endif // INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
